@@ -2,9 +2,10 @@
 """CSDM main."""
 import sys
 
-import csdmpy as cp
-from csdmpy.helper_functions import preview
+import matplotlib.pyplot as plt
 
+import csdmpy as cp
+from csdmpy.helper_functions import _preview
 
 __author__ = "Deepansh J. Srivastava"
 __email__ = "srivastava.89@osu.edu"
@@ -13,4 +14,5 @@ __email__ = "srivastava.89@osu.edu"
 if __name__ == "__main__":
     for i in range(len(sys.argv) - 1):
         data = cp.load(sys.argv[i + 1])
-        preview(data)
+        _preview(data)
+        plt.show()
