@@ -15,24 +15,21 @@ from .abstract_list import DependentVariableList  # lgtm [py/import-own-module]
 from .abstract_list import DimensionList  # lgtm [py/import-own-module]
 from .dependent_variables import (  # lgtm [py/import-own-module] # noqa: F401
     as_dependent_variable,
-)  # lgtm [py/unused-import]
+)
 from .dependent_variables import DependentVariable  # lgtm [py/import-own-module]
 from .dimensions import as_dimension  # lgtm [py/import-own-module]
 from .dimensions import Dimension  # lgtm [py/import-own-module] # noqa: F401
-from .dimensions import (  # lgtm [py/import-own-module] # noqa: F401
-    LabeledDimension,
-)  # lgtm [py/unused-import]
+from .dimensions import LabeledDimension  # lgtm [py/import-own-module] # noqa: F401
 from .dimensions import LinearDimension  # lgtm [py/import-own-module] # noqa: F401
-from .dimensions import (  # lgtm [py/import-own-module] # noqa: F401
-    MonotonicDimension,
-)  # lgtm [py/unused-import]
+from .dimensions import MonotonicDimension  # lgtm [py/import-own-module] # noqa: F401
+from .helper_functions import _preview  # lgtm [py/import-own-module]
 from .numpy_wrapper import fft
 from .units import string_to_quantity  # lgtm [py/import-own-module]
+from .utils import _check_dimension_indices  # lgtm [py/import-own-module]
 from .utils import _get_broadcast_shape  # lgtm [py/import-own-module]
 from .utils import check_scalar_object  # lgtm [py/import-own-module]
 from .utils import validate  # lgtm [py/import-own-module]
 
-
 __all__ = ["CSDM"]
 __ufunc_list_dimensionless_unit__ = [
     np.sin,
@@ -184,9 +181,7 @@ class CSDM:
     def __check_dimension_equality(self, other):
         """Check if the dimensions of the two csdm objects are identical."""
         if self.dimensions != other.dimensions:
-            raise Exception(
-                f"Cannot operate on CSDM objects with different dimensions."
-            )
+            raise Exception("Cannot operate on CSDM objects with different dimensions.")
 
     def __check_dependent_variable_len_equality(self, other):
         """
@@ -521,7 +516,7 @@ class CSDM:
         for variable in self.dependent_variables:
             section = (slice(0, len(variable.components), 1),) + indices[::-1]
             y = variable.components[section]
-            dv = empty_dependent_variable(variable.numeric_type)
+            dv = empty_dependent_variable(variable.numeric_type, variable.quantity_type)
             dv.subtype._components = y
             dv._copy_metadata(variable)
             csdm._dependent_variables += [dv]
@@ -696,7 +691,7 @@ class CSDM:
         Raises:
             AttributeError: When modified.
         """
-        dictionary = self._to_dict(filename=self.filename, for_display=True)
+        dictionary = self._dict(filename=self.filename, for_display=True)
 
         return json.dumps(dictionary, ensure_ascii=False, sort_keys=False, indent=2)
 
@@ -724,11 +719,10 @@ class CSDM:
         """Return a csdm object with a transpose of the dataset."""
         new = CSDM()
         new._copy_metadata(self)
-        # new = self.copy()
         new._dimensions += self._dimensions[::-1]
 
         for item in self.dependent_variables:
-            dv = empty_dependent_variable(item.numeric_type)
+            dv = empty_dependent_variable(item.numeric_type, item.quantity_type)
             dv._copy_metadata(item)
             dv.subtype._components = np.moveaxis(item.subtype._components.T, -1, 0)
             new._dependent_variables += [dv]
@@ -886,6 +880,10 @@ class CSDM:
         return
 
     def to_dict(self, update_timestamp=False, read_only=False):
+        """Alias to the `dict()` method of the class."""
+        return self.dict(update_timestamp, read_only)
+
+    def dict(self, update_timestamp=False, read_only=False):
         """
         Serialize the :ref:`CSDM_api` instance as a python dictionary.
 
@@ -894,7 +892,7 @@ class CSDM:
             read_only (bool): If true, the read_only flag is set true.
 
         Example:
-            >>> data.to_dict() # doctest: +SKIP
+            >>> data.dict() # doctest: +SKIP
             {'csdm': {'version': '1.0', 'timestamp': '1994-11-05T13:15:30Z',
             'geographic_coordinate': {'latitude': '10 deg', 'longitude': '93.2 deg',
             'altitude': '10 m'}, 'description': 'A simulated sine curve.',
@@ -906,9 +904,9 @@ class CSDM:
             'quantity_type': 'scalar', 'component_labels': ['response'],'components':
             ['AAAAABh5Fj9xeHM/cXhzPxh5Fj8yMQ0lGHkWv3F4c79xeHO/GHkWvw==']}]}}
         """
-        return self._to_dict(update_timestamp=update_timestamp, read_only=read_only)
+        return self._dict(update_timestamp=update_timestamp, read_only=read_only)
 
-    def _to_dict(
+    def _dict(
         self,
         filename=None,
         update_timestamp=False,
@@ -938,16 +936,20 @@ class CSDM:
 
         if self.description.strip() != "":
             dictionary["description"] = self.description
+
+        if self.application != {}:
+            dictionary["application"] = self.application
+
         dictionary["dimensions"] = []
         dictionary["dependent_variables"] = []
 
         for i in range(len(self.dimensions)):
-            dictionary["dimensions"].append(self.dimensions[i].to_dict())
+            dictionary["dimensions"].append(self.dimensions[i].dict())
 
         _length_of_dependent_variables = len(self.dependent_variables)
         for i in range(_length_of_dependent_variables):
             dictionary["dependent_variables"].append(
-                self.dependent_variables[i]._to_dict(
+                self.dependent_variables[i]._dict(
                     filename=filename,
                     dataset_index=i,
                     for_display=for_display,
@@ -978,7 +980,7 @@ class CSDM:
             >>> data.dumps()  # doctest: +SKIP
         """
         return json.dumps(
-            self._to_dict(update_timestamp, read_only, version),
+            self._dict(update_timestamp, read_only, version),
             ensure_ascii=False,
             sort_keys=False,
             allow_nan=False,
@@ -1036,7 +1038,7 @@ class CSDM:
             import os
             os.remove('my_file.csdf')
         """
-        dictionary = self._to_dict(filename=filename, version=version)
+        dictionary = self._dict(filename=filename, version=version)
 
         timestamp = datetime.datetime.utcnow().isoformat()[:-7] + "Z"
         dictionary["csdm"]["timestamp"] = timestamp
@@ -1111,7 +1113,7 @@ class CSDM:
         return deepcopy(self)
 
     def split(self):
-        """Split the dependent-variables into view of individual csdm objects.
+        """View of the dependent-variables as individual csdm objects.
 
         Return:
             A list of CSDM objects, each with one dependent variable. The
@@ -1425,42 +1427,36 @@ class CSDM:
     #     print(args)
     #     print(kwargs)
 
+    def plot(self, reverse_axis=None, range=None, **kwargs):
+        """
+        A supplementary function for plotting basic 1D and 2D datasets only.
 
-def _check_dimension_indices(d, index=-1):
-    """
-        Check the list of indexes to ensure that each index is an integer
-        and within the counts of dimensions.
-    """
+        Args:
+            csdm_object: The CSDM object.
+            reverse_axis: An ordered array of boolean specifying which dimensions will
+                be displayed on a reverse axis.
+            range: A list of minimum and maxmim coordinates along the dimensions. The
+                range along each dimension is given as [min, max]
+            kwargs: Additional keyword arguments are used in matplotlib plotting
+                functions. We implement the following matplotlib methods for the one
+                and two-dimensional datasets.
 
-    index = deepcopy(index)
+                - The 1D{1} scalar dataset use the plt.plot() method.
+                - The 1D{2} vector dataset use the plt.quiver() method.
+                - The 2D{1} scalar dataset use the plt.imshow() method if the two
+                  dimensions have a `linear` subtype. If any one of the dimension is
+                  `monotonic`, plt.NonUniformImage() method is used instead.
+                - The 2D{2} vector dataset use the plt.quiver() method.
+                - The 2D{3} pixel dataset use the plt.imshow(), assuming the pixel
+                  dataset as an RGB image.
 
-    def _correct_index(i, d):
-        if not isinstance(i, int):
-            raise TypeError(f"{message}, found {type(i)}")
-        if i < 0:
-            i += d
-        if i > d:
-            raise IndexError(
-                f"The `index` {index} cannot be greater than the total number of "
-                f"dimensions - 1, {d}."
-            )
-        return -1 - i
+        Returns:
+            A matplotlib figure instance.
 
-    message = "Index/Indices are expected as integer(s)"
-
-    if isinstance(index, tuple):
-        index = list(index)
-
-    if isinstance(index, (list, np.ndarray)):
-        for i, item in enumerate(index):
-            index[i] = _correct_index(item, d)
-        return tuple(index)
-
-    elif isinstance(index, int):
-        return tuple([_correct_index(index, d)])
-
-    else:
-        raise TypeError(f"{message}, found {type(index)}")
+        Example:
+            >>> cp.plot(data_object) # doctest: +SKIP
+        """
+        return _preview(self, reverse_axis, range, **kwargs)
 
 
 def _check_for_out(csdm, **kwargs):
@@ -1593,14 +1589,10 @@ def _get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
     return new
 
 
-def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
-    """
-    Perform the operation, func, on the components of the dependent variables, and
-    return the corresponding CSDM object.
-    """
+def _get_CSDM_object__args__axes(*args, **kwargs):
     axis = None
     args_ = []
-    if args is not ():
+    if args != ():
         csdm = args[0]
         args_ = list(args[1:])
         if len(args) > 1:
@@ -1615,6 +1607,15 @@ def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
             kwargs["axis"] = axis
 
     _check_for_out(csdm, **kwargs)
+    return csdm, args_, axis, kwargs
+
+
+def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
+    """
+    Perform the operation, func, on the components of the dependent variables, and
+    return the corresponding CSDM object.
+    """
+    csdm, args_, axis, kwargs = _get_CSDM_object__args__axes(*args, **kwargs)
 
     new = CSDM()
     lst = []
@@ -1645,9 +1646,9 @@ def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
 
     if axis is None:
         del new
-        if len(lst) > 1:
-            return lst
-        return lst[0]
+        # if len(lst) > 1:
+        #     return lst
+        return lst if len(lst) > 1 else lst[0]
 
     new._copy_metadata(csdm)
     return new
